//+------------------------------------------------------------------+
//|                                               NewsLoggerV1_0.mq4 |
//|                                               Paul Hampton-Smith |
//+------------------------------------------------------------------+

#include <NewsTrackerV1_0.mqh>

extern int nTimeWindowMinutes = 5;
extern bool bRecordTickLog = true; // .csv file of Bids & Asks
extern bool bRecordScreenShot = true; // screenshot nTimeWindowMinutes after event

int init()
{
   Comment("Waiting for tick");
   bNewsTrackerDebug = false;
   bNewsIsCached = false; // force reload of file
}

int deinit()
{
   Comment("");
}

int start()
{
   string strNextNews, strFilename;
   datetime NewsTimeServer;
   double dblParameters[MAX_PARAMETERS];
   static bool bScreenShotTaken = false;
   
   if ( NewsEvent(nTimeWindowMinutes, strNextNews, NewsTimeServer) )
   {
      Comment("Last tick was within 5 minutes of news event ",strNextNews,"\n     At UTC time: ",TimeToStr(ServerToUTC(NewsTimeServer)),"\n   At server time: ",TimeToStr(NewsTimeServer),"\n      At local time: ",TimeToStr(ServerToLocal(NewsTimeServer)));
      if (bRecordTickLog)
      {
      	strFilename = Symbol() + " " + strNextNews + " " + TimeToStr(ServerToUTC(NewsTimeServer)) + " UTC.csv";
         int handle = FileOpen(CleanFilename(strFilename), FILE_CSV|FILE_READ|FILE_WRITE, ',' );
         FileSeek(handle,0,SEEK_END);
         FileWrite(handle,MyTimeToString(CurTime()),Bid,Ask);
         FileClose(handle);
      }
      bScreenShotTaken = false;
      return(0);
   }
   else if (NewsTimeServer != 0)
      Comment("Next news event: ",strNextNews,"\n     At UTC time: ",TimeToStr(ServerToUTC(NewsTimeServer)),"\n   At server time: ",TimeToStr(NewsTimeServer),"\n      At local time: ",TimeToStr(ServerToLocal(NewsTimeServer)));
   else
      Comment("No future news event recorded for ",Symbol());


   // once time moves on from nTimeWindowMinutes, allow another 5 minutes for tick to arrive to collect screenshot
   
   if (bRecordScreenShot)
   {
	   if ( NextNews(strNextNews, NewsTimeServer, dblParameters, nTimeWindowMinutes+10 ) && !bScreenShotTaken && CurTime() > NewsTimeServer)
   	{
     		strFilename = Symbol() + " " + strNextNews + " " + TimeToStr(ServerToUTC(NewsTimeServer)) + " UTC.gif";
     		ObjectCreate(strNextNews,OBJ_VLINE,0,NewsTimeServer,0);
     		ObjectSet(strNextNews, OBJPROP_COLOR, Red);
     		ObjectSet(strNextNews, OBJPROP_STYLE, STYLE_DOT);
     		int nNewsBar = iBarShift(Symbol(),PERIOD_M1,NewsTimeServer,true);
     		string strInfo;
     		if (nNewsBar != -1)
     		{
     			strInfo = StringConcatenate("\nOpen ",iOpen(Symbol(),PERIOD_M1,nNewsBar),"\n High ",iHigh(Symbol(),PERIOD_M1,nNewsBar),"\n  Low ",iLow(Symbol(),PERIOD_M1,nNewsBar),"\nClose ",iClose(Symbol(),PERIOD_M1,nNewsBar));
     		}
     		else
     		{
     			strInfo = "\nNo 1 minute bar was created at news time";
     		}			
     		
         Comment("News event ",strNextNews,"\n     At UTC time: ",TimeToStr(ServerToUTC(NewsTimeServer)),"\n   At server time: ",TimeToStr(NewsTimeServer),"\n      At local time: ",TimeToStr(ServerToLocal(NewsTimeServer)), strInfo);
      	ScreenShot(CleanFilename(strFilename),640,480,-1,3,CHART_CANDLE);
      }
      bScreenShotTaken = true;
   }
   return(0);
}




